@@ -10,6 +10,23 @@ test_that("geom_vline_year handles basic functionality", {
 
   expect_no_error(p)
   expect_s3_class(p, "ggplot")
+  vdiffr::expect_doppelganger("1_geom_vline_year_basic", p)
+})
+
+test_that("geom_vline_year warning for non-date or datetime axis", {
+  test_dates <- data.frame(
+    date = as.numeric(as.Date("2023-12-01") + 0:60)
+  )
+
+  p <- ggplot(test_dates, aes(x = date)) +
+    geom_bar() +
+    geom_vline_year()
+
+  expect_no_error(p)
+  expect_s3_class(p, "ggplot")
+  expect_warning(vdiffr::expect_doppelganger("1_geom_vline_year_cont", p),
+    regexp = "x-axis is not date or datetime. Assuming date scale."
+  )
 })
 
 test_that("geom_vline_year handles datetime data", {
@@ -22,6 +39,7 @@ test_that("geom_vline_year handles datetime data", {
     geom_vline_year()
   expect_no_error(p)
   expect_s3_class(p, "ggplot")
+  vdiffr::expect_doppelganger("2_geom_vline_year_datetime", p)
 })
 
 test_that("geom_vline_year works with break_type='week'", {
@@ -36,6 +54,7 @@ test_that("geom_vline_year works with break_type='week'", {
 
   expect_no_error(p)
   expect_s3_class(p, "ggplot")
+  vdiffr::expect_doppelganger("3_geom_vline_year_week", p)
 
   # Test with MM-DD format that gets converted to week
   p2 <- ggplot(test_dates, aes(x = date)) +
@@ -44,22 +63,25 @@ test_that("geom_vline_year works with break_type='week'", {
 
   expect_no_error(p2)
   expect_s3_class(p2, "ggplot")
+  vdiffr::expect_doppelganger("3_geom_vline_year_week_mix", p2)
 
   # Test with mid-year week
   p3 <- ggplot(test_dates, aes(x = date)) +
     geom_bar() +
-    geom_vline_year(break_type = "week", year_break = "W26")
+    geom_vline_year(break_type = "week", year_break = "W05")
 
   expect_no_error(p3)
   expect_s3_class(p3, "ggplot")
+  vdiffr::expect_doppelganger("3_geom_vline_year_week2", p3)
 
   # Test calc MM-DD from week
   p4 <- ggplot(test_dates, aes(x = date)) +
     geom_bar() +
-    geom_vline_year(break_type = "day", year_break = "W26")
+    geom_vline_year(break_type = "day", year_break = "W03")
 
   expect_no_error(p4)
   expect_s3_class(p4, "ggplot")
+  vdiffr::expect_doppelganger("3_geom_vline_year_day_mix", p4)
 })
 
 test_that("geom_vline_year works with break_type='isoweek' and break_type='epiweek'", {
@@ -73,6 +95,7 @@ test_that("geom_vline_year works with break_type='isoweek' and break_type='epiwe
 
   expect_no_error(p)
   expect_s3_class(p, "ggplot")
+  vdiffr::expect_doppelganger("4_geom_vline_year_isoweek", p)
 
   p1 <- ggplot(test_dates, aes(x = date)) +
     geom_bar() +
@@ -80,14 +103,16 @@ test_that("geom_vline_year works with break_type='isoweek' and break_type='epiwe
 
   expect_no_error(p1)
   expect_s3_class(p1, "ggplot")
+  vdiffr::expect_doppelganger("4_geom_vline_year_epiweek", p1)
 
   # Test US epidemiological week for influenza season (week 40)
   p2 <- ggplot(test_dates, aes(x = date)) +
     geom_bar() +
-    geom_vline_year(break_type = "epiweek", year_break = "W40")
+    geom_vline_year(break_type = "epiweek", year_break = "W48")
 
   expect_no_error(p2)
   expect_s3_class(p2, "ggplot")
+  vdiffr::expect_doppelganger("4_geom_vline_year_epiweek2", p2)
 })
 
 test_that("geom_hline_year works with flipped coordinates", {
@@ -100,6 +125,7 @@ test_that("geom_hline_year works with flipped coordinates", {
     geom_hline_year()
   expect_no_error(p)
   expect_s3_class(p, "ggplot")
+  vdiffr::expect_doppelganger("5_geom_hline_year_basic", p)
 
   p1 <- ggplot(test_dates, aes(y = date)) +
     geom_bar() +
@@ -107,6 +133,7 @@ test_that("geom_hline_year works with flipped coordinates", {
 
   expect_no_error(p1)
   expect_s3_class(p1, "ggplot")
+  vdiffr::expect_doppelganger("5_geom_hline_year_basic2", p1)
 
   # Test week break
   p2 <- ggplot(test_dates, aes(y = date)) +
@@ -115,6 +142,7 @@ test_that("geom_hline_year works with flipped coordinates", {
 
   expect_no_error(p2)
   expect_s3_class(p2, "ggplot")
+  vdiffr::expect_doppelganger("5_geom_hline_year_week", p2)
 
   # Test isoweek break
   p3 <- ggplot(test_dates, aes(y = date)) +
@@ -123,6 +151,7 @@ test_that("geom_hline_year works with flipped coordinates", {
 
   expect_no_error(p3)
   expect_s3_class(p3, "ggplot")
+  vdiffr::expect_doppelganger("5_geom_hline_year_isoweek", p3)
 
   # Test epiweek break
   p4 <- ggplot(test_dates, aes(y = date)) +
@@ -131,6 +160,110 @@ test_that("geom_hline_year works with flipped coordinates", {
 
   expect_no_error(p4)
   expect_s3_class(p4, "ggplot")
+  vdiffr::expect_doppelganger("5_geom_hline_year_epiweek", p4)
+})
+
+test_that("Test draw_panel of GeomVline directly", {
+  # Mock data for panel_params
+  dummy_panel_params <- list(
+    x = list(scale = ggplot2::ScaleContinuousDate)
+  )
+
+  dummy_coord <- ggplot2::CoordCartesian
+  dummy_coord$backtransform_range <- function(params) {
+    list(
+      x = as.numeric(as_date(c("2022-12-15", "2023-01-24"))),
+      y = c(0, 10)
+    )
+  }
+
+  # Create a mock data frame
+  dummy_data <- data.frame(PANEL = 1)
+
+  # Test with default parameters
+  result <- expect_no_error(
+    GeomVlineYear$draw_panel(
+      data = dummy_data,
+      panel_params = dummy_panel_params,
+      coord = dummy_coord,
+      flipped_aes = FALSE,
+      year_break = "01-01",
+      break_type = "day",
+      just = NULL,
+      debug = TRUE
+    )
+  )
+
+  expect_identical(result$just, -0.5)
+  expect_identical(result$year, as.numeric(as_date("2023-01-01")))
+  expect_identical(result$data$x, as.numeric(as_date("2023-01-01")) + -0.5)
+
+  # Mock data for panel_params
+  dummy_panel_params <- list(
+    x = list(scale = ggplot2::ScaleContinuousDatetime)
+  )
+
+  dummy_coord <- ggplot2::CoordCartesian
+  dummy_coord$backtransform_range <- function(params) {
+    list(
+      x = as.numeric(as.POSIXct(c("2022-12-15", "2023-01-24"))),
+      y = c(0, 10)
+    )
+  }
+
+  # Test with default parameters
+  result <- expect_no_error(
+    GeomVlineYear$draw_panel(
+      data = dummy_data,
+      panel_params = dummy_panel_params,
+      coord = dummy_coord,
+      flipped_aes = FALSE,
+      year_break = "01-01",
+      break_type = "day",
+      just = NULL,
+      debug = TRUE
+    )
+  )
+
+  expect_identical(result$just, -0.5 * 60 * 60 * 24)
+  expect_identical(result$year, as.numeric(as_datetime("2023-01-01")))
+  expect_identical(result$data$x, as.numeric(as_datetime("2023-01-01")) + -0.5 * 60 * 60 * 24)
+
+  # Test with default parameters
+  result <- expect_no_error(
+    GeomVlineYear$draw_panel(
+      data = dummy_data,
+      panel_params = dummy_panel_params,
+      coord = dummy_coord,
+      flipped_aes = FALSE,
+      year_break = "01-01",
+      break_type = "day",
+      just = -2,
+      debug = TRUE
+    )
+  )
+
+  expect_identical(result$just, -2 * 60 * 60 * 24)
+  expect_identical(result$year, as.numeric(as_datetime("2023-01-01")))
+  expect_identical(result$data$x, as.numeric(as_datetime("2023-01-01")) + -2 * 60 * 60 * 24)
+
+
+  result <- expect_no_error(
+    GeomVlineYear$draw_panel(
+      data = dummy_data,
+      panel_params = dummy_panel_params,
+      coord = dummy_coord,
+      flipped_aes = FALSE,
+      year_break = "01-01",
+      break_type = "week",
+      just = NULL,
+      debug = TRUE
+    )
+  )
+
+  expect_identical(result$just, -3.5 * 60 * 60 * 24)
+  expect_identical(result$year, as.numeric(as_datetime("2023-01-02")))
+  expect_identical(result$data$x, as.numeric(as_datetime("2023-01-02")) + -3.5 * 60 * 60 * 24)
 })
 
 test_that("calc_visible_years handles date ranges correctly", {
@@ -152,7 +285,7 @@ test_that("calc_visible_years handles date ranges correctly", {
     .calc_visible_years(as.numeric(range), is_date = TRUE, break_type = "week", year_break = "test")
   )
 
-  expect_warning(expect_warning( # 2 warnings need to expect_warning() calls.
+  expect_warning(expect_warning( # 2 warnings need 2 expect_warning() calls.
     .calc_visible_years(as.numeric(range), is_date = TRUE, break_type = "day", year_break = "test")
   ))
 
